import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.account import (
    AccountAccountCounters,
    AccountInfo,
    AccountPushSettings,
    AccountUserSettings,
    ChangePasswordResponse,
    ChangePasswordResponseModel,
    GetActiveOffersResponse,
    GetActiveOffersResponseModel,
    GetAppPermissionsResponse,
    GetBannedResponse,
    GetBannedResponseModel,
    GetCountersResponse,
    GetInfoResponse,
    GetProfileInfoResponse,
    GetPushSettingsResponse,
    SaveProfileInfoResponse,
    SaveProfileInfoResponseModel,
)
from vkbottle_types.responses.base import OkResponse


class AccountCategory(BaseCategory):
    async def ban(self, owner_id: typing.Optional[int] = None, **kwargs) -> int:
        """account.ban method

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.ban", params)
        model = OkResponse
        return model(**response).response

    async def change_password(
        self,
        new_password: str,
        restore_sid: typing.Optional[str] = None,
        change_password_hash: typing.Optional[str] = None,
        old_password: typing.Optional[str] = None,
        **kwargs
    ) -> ChangePasswordResponseModel:
        """Changes a user password after access is successfully restored with the [vk.com/dev/auth.restore|auth.restore] method.

        :param new_password: New password that will be set as a current
        :param restore_sid: Session id received after the [vk.com/dev/auth.restore|auth.restore] method is executed. (If the password is changed right after the access was restored)
        :param change_password_hash: Hash received after a successful OAuth authorization with a code got by SMS. (If the password is changed right after the access was restored)
        :param old_password: Current user password.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.changePassword", params)
        model = ChangePasswordResponse
        return model(**response).response

    async def get_active_offers(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetActiveOffersResponseModel:
        """Returns a list of active ads (offers) which executed by the user will bring him/her respective number of votes to his balance in the application.

        :param offset:
        :param count: Number of results to return.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getActiveOffers", params)
        model = GetActiveOffersResponse
        return model(**response).response

    async def get_app_permissions(self, user_id: int, **kwargs) -> int:
        """Gets settings of the user in this application.

        :param user_id: User ID whose settings information shall be got. By default: current user.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getAppPermissions", params)
        model = GetAppPermissionsResponse
        return model(**response).response

    async def get_banned(
        self,
        offset: typing.Optional[int] = None,
        count: typing.Optional[int] = None,
        **kwargs
    ) -> GetBannedResponseModel:
        """Returns a user's blacklist.

        :param offset: Offset needed to return a specific subset of results.
        :param count: Number of results to return.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getBanned", params)
        model = GetBannedResponse
        return model(**response).response

    async def get_counters(
        self,
        filter: typing.Optional[typing.List[str]] = None,
        user_id: typing.Optional[int] = None,
        **kwargs
    ) -> AccountAccountCounters:
        """Returns non-null values of user counters.

        :param filter: Counters to be returned.
        :param user_id: User ID
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getCounters", params)
        model = GetCountersResponse
        return model(**response).response

    async def get_info(
        self, fields: typing.Optional[typing.List[str]] = None, **kwargs
    ) -> AccountInfo:
        """Returns current account info.

        :param fields: Fields to return. Possible values: *'country' — user country,, *'https_required' — is "HTTPS only" option enabled,, *'own_posts_default' — is "Show my posts only" option is enabled,, *'no_wall_replies' — are wall replies disabled or not,, *'intro' — is intro passed by user or not,, *'lang' — user language. By default: all.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getInfo", params)
        model = GetInfoResponse
        return model(**response).response

    async def get_profile_info(self, **kwargs) -> AccountUserSettings:
        """Returns the current account info."""

        params = self.get_set_params(locals())
        response = await self.api.request("account.getProfileInfo", params)
        model = GetProfileInfoResponse
        return model(**response).response

    async def get_push_settings(
        self, device_id: typing.Optional[str] = None, **kwargs
    ) -> AccountPushSettings:
        """Gets settings of push notifications.

        :param device_id: Unique device ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.getPushSettings", params)
        model = GetPushSettingsResponse
        return model(**response).response

    async def register_device(
        self,
        token: str,
        device_id: str,
        device_model: typing.Optional[str] = None,
        device_year: typing.Optional[int] = None,
        system_version: typing.Optional[str] = None,
        settings: typing.Optional[str] = None,
        sandbox: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Subscribes an iOS/Android/Windows Phone-based device to receive push notifications

        :param token: Device token used to send notifications. (for mpns, the token shall be URL for sending of notifications)
        :param device_id: Unique device ID.
        :param device_model: String name of device model.
        :param device_year: Device year.
        :param system_version: String version of device operating system.
        :param settings: Push settings in a [vk.com/dev/push_settings|special format].
        :param sandbox:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.registerDevice", params)
        model = OkResponse
        return model(**response).response

    async def save_profile_info(
        self,
        first_name: typing.Optional[str] = None,
        last_name: typing.Optional[str] = None,
        maiden_name: typing.Optional[str] = None,
        screen_name: typing.Optional[str] = None,
        cancel_request_id: typing.Optional[int] = None,
        sex: typing.Optional[Literal[0, 1, 2]] = None,
        relation: typing.Optional[Literal[1, 2, 3, 4, 5, 6, 7, 0]] = None,
        relation_partner_id: typing.Optional[int] = None,
        bdate: typing.Optional[str] = None,
        bdate_visibility: typing.Optional[Literal[1, 2, 0]] = None,
        home_town: typing.Optional[str] = None,
        country_id: typing.Optional[int] = None,
        city_id: typing.Optional[int] = None,
        status: typing.Optional[str] = None,
        **kwargs
    ) -> SaveProfileInfoResponseModel:
        """Edits current profile info.

        :param first_name: User first name.
        :param last_name: User last name.
        :param maiden_name: User maiden name (female only)
        :param screen_name: User screen name.
        :param cancel_request_id: ID of the name change request to be canceled. If this parameter is sent, all the others are ignored.
        :param sex: User sex. Possible values: , * '1' - female,, * '2' - male.
        :param relation: User relationship status. Possible values: , * '1' - single,, * '2' - in a relationship,, * '3' - engaged,, * '4' - married,, * '5' - it's complicated,, * '6' - actively searching,, * '7' - in love,, * '0' - not specified.
        :param relation_partner_id: ID of the relationship partner.
        :param bdate: User birth date, format: DD.MM.YYYY.
        :param bdate_visibility: Birth date visibility. Returned values: , * '1' - show birth date,, * '2' - show only month and day,, * '0' - hide birth date.
        :param home_town: User home town.
        :param country_id: User country.
        :param city_id: User city.
        :param status: Status text.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.saveProfileInfo", params)
        model = SaveProfileInfoResponse
        return model(**response).response

    async def set_info(
        self,
        name: typing.Optional[
            Literal["intro", "no_wall_replies", "own_posts_default"]
        ] = None,
        value: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Allows to edit the current account info.

        :param name: Setting name.
        :param value: Setting value.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setInfo", params)
        model = OkResponse
        return model(**response).response

    async def set_offline(self, **kwargs) -> int:
        """Marks a current user as offline."""

        params = self.get_set_params(locals())
        response = await self.api.request("account.setOffline", params)
        model = OkResponse
        return model(**response).response

    async def set_online(self, voip: typing.Optional[bool] = None, **kwargs) -> int:
        """Marks the current user as online for 15 minutes.

        :param voip: '1' if videocalls are available for current device.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setOnline", params)
        model = OkResponse
        return model(**response).response

    async def set_push_settings(
        self,
        device_id: str,
        settings: typing.Optional[str] = None,
        key: typing.Optional[str] = None,
        value: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> int:
        """Change push settings.

        :param device_id: Unique device ID.
        :param settings: Push settings in a [vk.com/dev/push_settings|special format].
        :param key: Notification key.
        :param value: New value for the key in a [vk.com/dev/push_settings|special format].
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setPushSettings", params)
        model = OkResponse
        return model(**response).response

    async def set_silence_mode(
        self,
        device_id: typing.Optional[str] = None,
        time: typing.Optional[int] = None,
        peer_id: typing.Optional[int] = None,
        sound: typing.Optional[int] = None,
        **kwargs
    ) -> int:
        """Mutes push notifications for the set period of time.

        :param device_id: Unique device ID.
        :param time: Time in seconds for what notifications should be disabled. '-1' to disable forever.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        :param sound: '1' — to enable sound in this dialog, '0' — to disable sound. Only if 'peer_id' contains user or community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.setSilenceMode", params)
        model = OkResponse
        return model(**response).response

    async def unban(self, owner_id: typing.Optional[int] = None, **kwargs) -> int:
        """account.unban method

        :param owner_id:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.unban", params)
        model = OkResponse
        return model(**response).response

    async def unregister_device(
        self,
        device_id: typing.Optional[str] = None,
        sandbox: typing.Optional[bool] = None,
        **kwargs
    ) -> int:
        """Unsubscribes a device from push notifications.

        :param device_id: Unique device ID.
        :param sandbox:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("account.unregisterDevice", params)
        model = OkResponse
        return model(**response).response


__all__ = ("AccountCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    PagesWikipage,
    PagesWikipageFull,
    PagesWikipageHistory,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetHistoryResponse(BaseResponse):
    response: typing.List["PagesWikipageHistory"]


class GetTitlesResponse(BaseResponse):
    response: typing.List["PagesWikipage"]


class GetVersionResponse(BaseResponse):
    response: PagesWikipageFull


class GetResponse(BaseResponse):
    response: PagesWikipageFull


class ParseWikiResponse(BaseResponse):
    response: str


class SaveAccessResponse(BaseResponse):
    response: int


class SaveResponse(BaseResponse):
    response: int


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetHistoryResponse",
    "GetResponse",
    "GetTitlesResponse",
    "GetVersionResponse",
    "PagesWikipage",
    "PagesWikipageFull",
    "PagesWikipageHistory",
    "ParseWikiResponse",
    "SaveAccessResponse",
    "SaveResponse",
)



import inspect
import typing

from vkbottle_types.objects import (
    GroupsGroupsArray,
    UsersSubscriptionsItem,
    UsersUserFull,
    UsersUsersArray,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetFollowersFieldsResponse(BaseResponse):
    response: "GetFollowersFieldsResponseModel"


class GetFollowersResponse(BaseResponse):
    response: "GetFollowersResponseModel"


class GetSubscriptionsExtendedResponse(BaseResponse):
    response: "GetSubscriptionsExtendedResponseModel"


class GetSubscriptionsResponse(BaseResponse):
    response: "GetSubscriptionsResponseModel"


class GetResponse(BaseResponse):
    response: typing.List["UsersUserFull"]


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class GetFollowersFieldsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetFollowersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetSubscriptionsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersSubscriptionsItem"]] = None


class GetSubscriptionsResponseModel(BaseResponse):
    users: typing.Optional["UsersUsersArray"] = None
    groups: typing.Optional["GroupsGroupsArray"] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetFollowersFieldsResponse",
    "GetFollowersFieldsResponseModel",
    "GetFollowersResponse",
    "GetFollowersResponseModel",
    "GetResponse",
    "GetSubscriptionsExtendedResponse",
    "GetSubscriptionsExtendedResponseModel",
    "GetSubscriptionsResponse",
    "GetSubscriptionsResponseModel",
    "GroupsGroupsArray",
    "SearchResponse",
    "SearchResponseModel",
    "UsersSubscriptionsItem",
    "UsersUserFull",
    "UsersUsersArray",
)



import inspect
import typing

from vkbottle_types.objects import (
    AdswebGetAdCategoriesResponseCategoriesCategory,
    AdswebGetAdUnitsResponseAdUnitsAdUnit,
    AdswebGetFraudHistoryResponseEntriesEntry,
    AdswebGetSitesResponseSitesSite,
    AdswebGetStatisticsResponseItemsItem,
)
from vkbottle_types.responses.base_response import BaseResponse


class GetAdCategoriesResponse(BaseResponse):
    response: "GetAdCategoriesResponseModel"


class GetAdUnitCodeResponse(BaseResponse):
    response: "GetAdUnitCodeResponseModel"


class GetAdUnitsResponse(BaseResponse):
    response: "GetAdUnitsResponseModel"


class GetFraudHistoryResponse(BaseResponse):
    response: "GetFraudHistoryResponseModel"


class GetSitesResponse(BaseResponse):
    response: "GetSitesResponseModel"


class GetStatisticsResponse(BaseResponse):
    response: "GetStatisticsResponseModel"


class GetAdCategoriesResponseModel(BaseResponse):
    categories: typing.Optional[
        typing.List["AdswebGetAdCategoriesResponseCategoriesCategory"]
    ] = None


class GetAdUnitCodeResponseModel(BaseResponse):
    html: typing.Optional[str] = None


class GetAdUnitsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    ad_units: typing.Optional[
        typing.List["AdswebGetAdUnitsResponseAdUnitsAdUnit"]
    ] = None


class GetFraudHistoryResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    entries: typing.Optional[
        typing.List["AdswebGetFraudHistoryResponseEntriesEntry"]
    ] = None


class GetSitesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    sites: typing.Optional[typing.List["AdswebGetSitesResponseSitesSite"]] = None


class GetStatisticsResponseModel(BaseResponse):
    next_page_id: typing.Optional[str] = None
    items: typing.Optional[typing.List["AdswebGetStatisticsResponseItemsItem"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AdswebGetAdCategoriesResponseCategoriesCategory",
    "AdswebGetAdUnitsResponseAdUnitsAdUnit",
    "AdswebGetFraudHistoryResponseEntriesEntry",
    "AdswebGetSitesResponseSitesSite",
    "AdswebGetStatisticsResponseItemsItem",
    "GetAdCategoriesResponse",
    "GetAdCategoriesResponseModel",
    "GetAdUnitCodeResponse",
    "GetAdUnitCodeResponseModel",
    "GetAdUnitsResponse",
    "GetAdUnitsResponseModel",
    "GetFraudHistoryResponse",
    "GetFraudHistoryResponseModel",
    "GetSitesResponse",
    "GetSitesResponseModel",
    "GetStatisticsResponse",
    "GetStatisticsResponseModel",
)



from enum import IntEnum


class UserEventType(IntEnum):
    UNDEFINED_EVENT = -1

    REPLACE_MESSAGE_FLAGS = 1
    INSTALL_MESSAGE_FLAGS = 2
    RESET_MESSAGE_FLAGS = 3

    MESSAGE_NEW = 4
    MESSAGE_EDIT = 5
    IN_READ = 6
    OUT_READ = 7
    FRIEND_ONLINE = 8
    FRIEND_OFFLINE = 9
    RESET_DIALOG_FLAGS = 10
    REPLACE_DIALOG_FLAGS = 11
    INSTALL_DIALOG_FLAGS = 12
    MESSAGES_DELETE = 13
    MESSAGES_RESTORE = 14

    MESSAGE_CHANGE = 18
    CLEAR_MESSAGE_CACHE = 19

    CHANGE_MAJOR_ID = 20
    CHANGE_MINOR_ID = 21

    CHAT_EDIT = 51
    CHAT_INFO_EDIT = 52
    DIALOG_TYPING_STATE = 61

    CHAT_TYPING_STATE = 62
    USERS_TYPING_STATE = 63
    CHAT_VOICE_MESSAGE_STATES = 64
    PHOTO_UPLOAD_STATE = 65
    VIDEO_UPLOAD_STATE = 66
    FILE_UPLOAD_STATE = 67

    CALL = 70
    COUNTER = 80
    USER_INVISIBLE_CHANGE = 81
    NOTIFICATIONS_SETTINGS_CHANGED = 114
    CHAT_CALL = 115
    CALLBACK_BUTTON_REPLY = 119



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['vkbottle_types',
 'vkbottle_types.codegen',
 'vkbottle_types.codegen.methods',
 'vkbottle_types.codegen.responses',
 'vkbottle_types.events',
 'vkbottle_types.events.enums',
 'vkbottle_types.events.objects',
 'vkbottle_types.methods',
 'vkbottle_types.responses']

package_data = \
{'': ['*']}

install_requires = \
['pydantic>=1.6.1,<2.0.0', 'vkbottle>=4.1,<5.0']

setup_kwargs = {
    'name': 'vkbottle-types',
    'version': '5.131.146.3',
    'description': 'Types for vkbottle',
    'long_description': None,
    'author': 'timoniq',
    'author_email': None,
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7.2,<4.0.0',
}


setup(**setup_kwargs)



from vkbottle_types.responses.groups import (
    GetMembersResponse,
    GetMembersResponseModel,
    GetMembersFieldsResponse,
    GetMembersFieldsResponseModel,
    GetMembersFilterManagersResponse,
    GetMembersFilterManagersResponseModel,
    GetMembersFieldsFilterManagersResponse,
    GetMembersFieldsFilterManagersResponseModel,
)

from vkbottle_types.codegen.methods.groups import GroupsCategory
from typing_extensions import Literal
from typing import Optional, List, overload, Union


class GroupsCategory(GroupsCategory):
    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[Literal[None]] = ...,
        filter: Optional[Literal["friends", "unsure", "donut"]] = ...,
        **kwargs
    ) -> GetMembersResponseModel:
        ...

    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: List[str] = ...,
        filter: Optional[Literal[None]] = ...,
        **kwargs
    ) -> GetMembersFieldsResponseModel:
        ...

    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: Optional[Literal[None]] = ...,
        filter: Literal["managers"] = ...,
        **kwargs
    ) -> GetMembersFilterManagersResponseModel:
        ...

    @overload
    async def get_members(
        self,
        group_id: Optional[str] = None,
        sort: Optional[Literal["id_asc", "id_desc", "time_asc", "time_desc"]] = None,
        offset: Optional[int] = None,
        count: Optional[int] = None,
        fields: List[str] = ...,
        filter: Literal["managers"] = ...,
        **kwargs
    ) -> GetMembersFieldsFilterManagersResponseModel:
        ...

    async def get_members(
        self,
        group_id=None,
        sort=None,
        offset=None,
        count=None,
        fields=None,
        filter=None,
        **kwargs
    ) -> Union[
        GetMembersResponseModel,
        GetMembersFieldsResponseModel,
        GetMembersFilterManagersResponseModel,
        GetMembersFieldsFilterManagersResponseModel,
    ]:
        """Returns a list of community members.

        :param group_id: ID or screen name of the community.
        :param sort: Sort order. Available values: 'id_asc', 'id_desc', 'time_asc', 'time_desc'. 'time_asc' and 'time_desc' are availavle only if the method is called by the group's 'moderator'.
        :param offset: Offset needed to return a specific subset of community members.
        :param count: Number of community members to return.
        :param fields: List of additional fields to be returned. Available values: 'sex, bdate, city, country, photo_50, photo_100, photo_200_orig, photo_200, photo_400_orig, photo_max, photo_max_orig, online, online_mobile, lists, domain, has_mobile, contacts, connections, site, education, universities, schools, can_post, can_see_all_posts, can_see_audio, can_write_private_message, status, last_seen, common_count, relation, relatives, counters'.
        :param filter: *'friends' - only friends in this community will be returned,, *'unsure' - only those who pressed 'I may attend' will be returned (if it's an event).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("groups.getMembers", params)
        model = self.get_model(
            (
                (("fields",), GetMembersFieldsResponse),
                ((["filter", "managers"],), GetMembersFilterManagersResponse),
                (
                    (["filter", "managers"], "fields"),
                    GetMembersFieldsFilterManagersResponse,
                ),
            ),
            default=GetMembersResponse,
            params=params,
        )
        return model(**response).response



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseBoolInt
from vkbottle_types.responses.notifications import (
    GetResponse,
    GetResponseModel,
    MarkAsViewedResponse,
    NotificationsSendMessageItem,
    SendMessageResponse,
)


class NotificationsCategory(BaseCategory):
    async def get(
        self,
        count: typing.Optional[int] = None,
        start_from: typing.Optional[str] = None,
        filters: typing.Optional[typing.List[str]] = None,
        start_time: typing.Optional[int] = None,
        end_time: typing.Optional[int] = None,
        **kwargs
    ) -> GetResponseModel:
        """Returns a list of notifications about other users' feedback to the current user's wall posts.

        :param count: Number of notifications to return.
        :param start_from:
        :param filters: Type of notifications to return: 'wall' — wall posts, 'mentions' — mentions in wall posts, comments, or topics, 'comments' — comments to wall posts, photos, and videos, 'likes' — likes, 'reposted' — wall posts that are copied from the current user's wall, 'followers' — new followers, 'friends' — accepted friend requests
        :param start_time: Earliest timestamp (in Unix time) of a notification to return. By default, 24 hours ago.
        :param end_time: Latest timestamp (in Unix time) of a notification to return. By default, the current time.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notifications.get", params)
        model = GetResponse
        return model(**response).response

    async def mark_as_viewed(self, **kwargs) -> BaseBoolInt:
        """Resets the counter of new notifications about other users' feedback to the current user's wall posts."""

        params = self.get_set_params(locals())
        response = await self.api.request("notifications.markAsViewed", params)
        model = MarkAsViewedResponse
        return model(**response).response

    async def send_message(
        self,
        user_ids: typing.List[int],
        message: str,
        fragment: typing.Optional[str] = None,
        group_id: typing.Optional[int] = None,
        random_id: typing.Optional[int] = None,
        sending_mode: typing.Optional[
            Literal["delayed", "delayed_push", "immediately"]
        ] = None,
        **kwargs
    ) -> typing.List[NotificationsSendMessageItem]:
        """notifications.sendMessage method

        :param user_ids:
        :param message:
        :param fragment:
        :param group_id:
        :param random_id:
        :param sending_mode: Type of sending (delivering) notifications: 'immediately' — push and bell notifications will be delivered as soon as possible, 'delayed' — push and bell notifications will be delivered in the most comfortable time for the user, 'delayed_push' — only push notifications will be delivered in the most comfortable time, while the bell notifications will be delivered as soon as possible
        """

        params = self.get_set_params(locals())
        response = await self.api.request("notifications.sendMessage", params)
        model = SendMessageResponse
        return model(**response).response


__all__ = ("NotificationsCategory",)



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    GroupsGroup,
    GroupsGroupFull,
    UsersUser,
    UsersUserFull,
    VideoSaveResult,
    VideoVideoAlbum,
    VideoVideoAlbumFull,
    VideoVideoFull,
    WallWallComment,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddAlbumResponse(BaseResponse):
    response: "AddAlbumResponseModel"


class ChangeVideoAlbumsResponse(BaseResponse):
    response: typing.List[int]


class CreateCommentResponse(BaseResponse):
    response: int


class GetAlbumByIdResponse(BaseResponse):
    response: VideoVideoAlbumFull


class GetAlbumsByVideoExtendedResponse(BaseResponse):
    response: "GetAlbumsByVideoExtendedResponseModel"


class GetAlbumsByVideoResponse(BaseResponse):
    response: typing.List[int]


class GetAlbumsExtendedResponse(BaseResponse):
    response: "GetAlbumsExtendedResponseModel"


class GetAlbumsResponse(BaseResponse):
    response: "GetAlbumsResponseModel"


class GetCommentsExtendedResponse(BaseResponse):
    response: "GetCommentsExtendedResponseModel"


class GetCommentsResponse(BaseResponse):
    response: "GetCommentsResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class RestoreCommentResponse(BaseResponse):
    response: BaseBoolInt


class SaveResponse(BaseResponse):
    response: VideoSaveResult


class SearchExtendedResponse(BaseResponse):
    response: "SearchExtendedResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class UploadResponse(BaseResponse):
    response: "UploadResponseModel"


class AddAlbumResponseModel(BaseResponse):
    album_id: typing.Optional[int] = None


class GetAlbumsByVideoExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["VideoVideoAlbumFull"]] = None


class GetAlbumsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["VideoVideoAlbumFull"]] = None


class GetAlbumsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["VideoVideoAlbum"]] = None


class GetCommentsExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroup"]] = None
    current_level_count: typing.Optional[int] = None
    can_post: typing.Optional[bool] = None
    show_reply_button: typing.Optional[bool] = None
    groups_can_post: typing.Optional[bool] = None
    real_offset: typing.Optional[int] = None


class GetCommentsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["WallWallComment"]] = None
    current_level_count: typing.Optional[int] = None
    can_post: typing.Optional[bool] = None
    show_reply_button: typing.Optional[bool] = None
    groups_can_post: typing.Optional[bool] = None
    real_offset: typing.Optional[int] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["VideoVideoFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserFull"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class SearchExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["VideoVideoFull"]] = None
    profiles: typing.Optional[typing.List["UsersUser"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["VideoVideoFull"]] = None


class UploadResponseModel(BaseResponse):
    size: typing.Optional[int] = None
    video_id: typing.Optional[int] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddAlbumResponse",
    "AddAlbumResponseModel",
    "BaseBoolInt",
    "ChangeVideoAlbumsResponse",
    "CreateCommentResponse",
    "GetAlbumByIdResponse",
    "GetAlbumsByVideoExtendedResponse",
    "GetAlbumsByVideoExtendedResponseModel",
    "GetAlbumsByVideoResponse",
    "GetAlbumsExtendedResponse",
    "GetAlbumsExtendedResponseModel",
    "GetAlbumsResponse",
    "GetAlbumsResponseModel",
    "GetCommentsExtendedResponse",
    "GetCommentsExtendedResponseModel",
    "GetCommentsResponse",
    "GetCommentsResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GroupsGroup",
    "GroupsGroupFull",
    "RestoreCommentResponse",
    "SaveResponse",
    "SearchExtendedResponse",
    "SearchExtendedResponseModel",
    "SearchResponse",
    "SearchResponseModel",
    "UploadResponse",
    "UploadResponseModel",
    "UsersUser",
    "UsersUserFull",
    "VideoSaveResult",
    "VideoVideoAlbum",
    "VideoVideoAlbumFull",
    "VideoVideoFull",
    "WallWallComment",
)



import inspect
import typing

from vkbottle_types.objects import PrettyCardsPrettyCard, PrettyCardsPrettyCardOrError
from vkbottle_types.responses.base_response import BaseResponse


class CreateResponse(BaseResponse):
    response: "CreateResponseModel"


class DeleteResponse(BaseResponse):
    response: "DeleteResponseModel"


class EditResponse(BaseResponse):
    response: "EditResponseModel"


class GetByIdResponse(BaseResponse):
    response: typing.List["PrettyCardsPrettyCardOrError"]


class GetUploadURLResponse(BaseResponse):
    response: str


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class CreateResponseModel(BaseResponse):
    owner_id: typing.Optional[int] = None
    card_id: typing.Optional[str] = None


class DeleteResponseModel(BaseResponse):
    owner_id: typing.Optional[int] = None
    card_id: typing.Optional[str] = None
    error: typing.Optional[str] = None


class EditResponseModel(BaseResponse):
    owner_id: typing.Optional[int] = None
    card_id: typing.Optional[str] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["PrettyCardsPrettyCard"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "CreateResponse",
    "CreateResponseModel",
    "DeleteResponse",
    "DeleteResponseModel",
    "EditResponse",
    "EditResponseModel",
    "GetByIdResponse",
    "GetResponse",
    "GetResponseModel",
    "GetUploadURLResponse",
    "PrettyCardsPrettyCard",
    "PrettyCardsPrettyCardOrError",
)



import typing

from typing_extensions import Literal
from vkbottle_types.methods.base_category import BaseCategory
from vkbottle_types.responses.base import BaseGetUploadServerResponse, OkResponse
from vkbottle_types.responses.docs import (
    AddResponse,
    BaseUploadServer,
    DocsDoc,
    GetByIdResponse,
    GetResponse,
    GetResponseModel,
    GetTypesResponse,
    GetTypesResponseModel,
    GetUploadServerResponse,
    SaveResponse,
    SaveResponseModel,
    SearchResponse,
    SearchResponseModel,
)


class DocsCategory(BaseCategory):
    async def add(
        self,
        owner_id: int,
        doc_id: int,
        access_key: typing.Optional[str] = None,
        **kwargs
    ) -> int:
        """Copies a document to a user's or community's document list.

        :param owner_id: ID of the user or community that owns the document. Use a negative value to designate a community ID.
        :param doc_id: Document ID.
        :param access_key: Access key. This parameter is required if 'access_key' was returned with the document's data.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.add", params)
        model = AddResponse
        return model(**response).response

    async def delete(self, owner_id: int, doc_id: int, **kwargs) -> int:
        """Deletes a user or community document.

        :param owner_id: ID of the user or community that owns the document. Use a negative value to designate a community ID.
        :param doc_id: Document ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.delete", params)
        model = OkResponse
        return model(**response).response

    async def edit(
        self,
        owner_id: int,
        doc_id: int,
        title: str,
        tags: typing.Optional[typing.List[str]] = None,
        **kwargs
    ) -> int:
        """Edits a document.

        :param owner_id: User ID or community ID. Use a negative value to designate a community ID.
        :param doc_id: Document ID.
        :param title: Document title.
        :param tags: Document tags.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.edit", params)
        model = OkResponse
        return model(**response).response

    async def get(
        self,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        type: typing.Optional[Literal[0, 1, 2, 3, 4, 5, 6, 7, 8]] = None,
        owner_id: typing.Optional[int] = None,
        return_tags: typing.Optional[bool] = None,
        **kwargs
    ) -> GetResponseModel:
        """Returns detailed information about user or community documents.

        :param count: Number of documents to return. By default, all documents.
        :param offset: Offset needed to return a specific subset of documents.
        :param type:
        :param owner_id: ID of the user or community that owns the documents. Use a negative value to designate a community ID.
        :param return_tags:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.get", params)
        model = GetResponse
        return model(**response).response

    async def get_by_id(
        self,
        docs: typing.List[str],
        return_tags: typing.Optional[bool] = None,
        **kwargs
    ) -> typing.List[DocsDoc]:
        """Returns information about documents by their IDs.

        :param docs: Document IDs. Example: , "66748_91488,66748_91455",
        :param return_tags:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getById", params)
        model = GetByIdResponse
        return model(**response).response

    async def get_messages_upload_server(
        self,
        type: typing.Optional[Literal["audio_message", "doc", "graffiti"]] = None,
        peer_id: typing.Optional[int] = None,
        **kwargs
    ) -> BaseUploadServer:
        """Returns the server address for document upload.

        :param type: Document type.
        :param peer_id: Destination ID. "For user: 'User ID', e.g. '12345'. For chat: '2000000000' + 'Chat ID', e.g. '2000000001'. For community: '- Community ID', e.g. '-12345'. "
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getMessagesUploadServer", params)
        model = GetUploadServerResponse
        return model(**response).response

    async def get_types(self, owner_id: int, **kwargs) -> GetTypesResponseModel:
        """Returns documents types available for current user.

        :param owner_id: ID of the user or community that owns the documents. Use a negative value to designate a community ID.
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getTypes", params)
        model = GetTypesResponse
        return model(**response).response

    async def get_upload_server(
        self, group_id: typing.Optional[int] = None, **kwargs
    ) -> BaseUploadServer:
        """Returns the server address for document upload.

        :param group_id: Community ID (if the document will be uploaded to the community).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getUploadServer", params)
        model = GetUploadServerResponse
        return model(**response).response

    async def get_wall_upload_server(
        self, group_id: typing.Optional[int] = None, **kwargs
    ) -> BaseUploadServer:
        """Returns the server address for document upload onto a user's or community's wall.

        :param group_id: Community ID (if the document will be uploaded to the community).
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.getWallUploadServer", params)
        model = BaseGetUploadServerResponse
        return model(**response).response

    async def save(
        self,
        file: str,
        title: typing.Optional[str] = None,
        tags: typing.Optional[str] = None,
        return_tags: typing.Optional[bool] = None,
        **kwargs
    ) -> SaveResponseModel:
        """Saves a document after [vk.com/dev/upload_files_2|uploading it to a server].

        :param file: This parameter is returned when the file is [vk.com/dev/upload_files_2|uploaded to the server].
        :param title: Document title.
        :param tags: Document tags.
        :param return_tags:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.save", params)
        model = SaveResponse
        return model(**response).response

    async def search(
        self,
        q: str,
        search_own: typing.Optional[bool] = None,
        count: typing.Optional[int] = None,
        offset: typing.Optional[int] = None,
        return_tags: typing.Optional[bool] = None,
        **kwargs
    ) -> SearchResponseModel:
        """Returns a list of documents matching the search criteria.

        :param q: Search query string.
        :param search_own:
        :param count: Number of results to return.
        :param offset: Offset needed to return a specific subset of results.
        :param return_tags:
        """

        params = self.get_set_params(locals())
        response = await self.api.request("docs.search", params)
        model = SearchResponse
        return model(**response).response


__all__ = ("DocsCategory",)



import inspect

from vkbottle_types.objects import StatusStatus
from vkbottle_types.responses.base_response import BaseResponse


class GetResponse(BaseResponse):
    response: StatusStatus


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "GetResponse",
    "StatusStatus",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    GroupsAddress,
    GroupsBannedItem,
    GroupsCallbackServer,
    GroupsCallbackSettings,
    GroupsGroup,
    GroupsGroupAccess,
    GroupsGroupAgeLimits,
    GroupsGroupAudio,
    GroupsGroupCategory,
    GroupsGroupCategoryFull,
    GroupsGroupDocs,
    GroupsGroupFull,
    GroupsGroupFullSection,
    GroupsGroupPhotos,
    GroupsGroupPublicCategoryList,
    GroupsGroupSuggestedPrivacy,
    GroupsGroupTag,
    GroupsGroupTopics,
    GroupsGroupVideo,
    GroupsGroupWall,
    GroupsGroupWiki,
    GroupsLinksItem,
    GroupsLongPollServer,
    GroupsLongPollSettings,
    GroupsMemberRole,
    GroupsMemberStatus,
    GroupsMemberStatusFull,
    GroupsSectionsListItem,
    GroupsSettingsTwitter,
    GroupsSubjectItem,
    GroupsTokenPermissionSetting,
    GroupsUserXtrRole,
    UsersUserFull,
    UsersUserMin,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddAddressResponse(BaseResponse):
    response: GroupsAddress


class AddCallbackServerResponse(BaseResponse):
    response: "AddCallbackServerResponseModel"


class AddLinkResponse(BaseResponse):
    response: GroupsLinksItem


class CreateResponse(BaseResponse):
    response: GroupsGroup


class EditAddressResponse(BaseResponse):
    response: GroupsAddress


class GetAddressesResponse(BaseResponse):
    response: "GetAddressesResponseModel"


class GetBannedResponse(BaseResponse):
    response: "GetBannedResponseModel"


class GetByIdObjectLegacyResponse(BaseResponse):
    response: typing.List["GroupsGroupFull"]


class GetCallbackConfirmationCodeResponse(BaseResponse):
    response: "GetCallbackConfirmationCodeResponseModel"


class GetCallbackServersResponse(BaseResponse):
    response: "GetCallbackServersResponseModel"


class GetCallbackSettingsResponse(BaseResponse):
    response: GroupsCallbackSettings


class GetCatalogInfoExtendedResponse(BaseResponse):
    response: "GetCatalogInfoExtendedResponseModel"


class GetCatalogInfoResponse(BaseResponse):
    response: "GetCatalogInfoResponseModel"


class GetCatalogResponse(BaseResponse):
    response: "GetCatalogResponseModel"


class GetInvitedUsersResponse(BaseResponse):
    response: "GetInvitedUsersResponseModel"


class GetInvitesExtendedResponse(BaseResponse):
    response: "GetInvitesExtendedResponseModel"


class GetInvitesResponse(BaseResponse):
    response: "GetInvitesResponseModel"


class GetLongPollServerResponse(BaseResponse):
    response: GroupsLongPollServer


class GetLongPollSettingsResponse(BaseResponse):
    response: GroupsLongPollSettings


class GetMembersFieldsResponse(BaseResponse):
    response: "GetMembersFieldsResponseModel"


class GetMembersFilterResponse(BaseResponse):
    response: "GetMembersFilterResponseModel"


class GetMembersResponse(BaseResponse):
    response: "GetMembersResponseModel"


class GetRequestsFieldsResponse(BaseResponse):
    response: "GetRequestsFieldsResponseModel"


class GetRequestsResponse(BaseResponse):
    response: "GetRequestsResponseModel"


class GetSettingsResponse(BaseResponse):
    response: "GetSettingsResponseModel"


class GetTagListResponse(BaseResponse):
    response: typing.List["GroupsGroupTag"]


class GetTokenPermissionsResponse(BaseResponse):
    response: "GetTokenPermissionsResponseModel"


class GetObjectExtendedResponse(BaseResponse):
    response: "GetObjectExtendedResponseModel"


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class IsMemberExtendedResponse(BaseResponse):
    response: "IsMemberExtendedResponseModel"


class IsMemberResponse(BaseResponse):
    response: BaseBoolInt


class IsMemberUserIdsExtendedResponse(BaseResponse):
    response: typing.List["GroupsMemberStatusFull"]


class IsMemberUserIdsResponse(BaseResponse):
    response: typing.List["GroupsMemberStatus"]


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class AddCallbackServerResponseModel(BaseResponse):
    server_id: typing.Optional[int] = None


class GetAddressesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsAddress"]] = None


class GetBannedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsBannedItem"]] = None


class GetCallbackConfirmationCodeResponseModel(BaseResponse):
    code: typing.Optional[str] = None


class GetCallbackServersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsCallbackServer"]] = None


class GetCatalogInfoExtendedResponseModel(BaseResponse):
    enabled: typing.Optional["BaseBoolInt"] = None
    categories: typing.Optional[typing.List["GroupsGroupCategoryFull"]] = None


class GetCatalogInfoResponseModel(BaseResponse):
    enabled: typing.Optional["BaseBoolInt"] = None
    categories: typing.Optional[typing.List["GroupsGroupCategory"]] = None


class GetCatalogResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroup"]] = None


class GetInvitedUsersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetInvitesExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroupFull"]] = None
    profiles: typing.Optional[typing.List["UsersUserMin"]] = None
    groups: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetInvitesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetMembersFieldsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsUserXtrRole"]] = None


class GetMembersFilterResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsMemberRole"]] = None


class GetMembersResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetRequestsFieldsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["UsersUserFull"]] = None


class GetRequestsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class GetSettingsResponseModel(BaseResponse):
    access: typing.Optional["GroupsGroupAccess"] = None
    address: typing.Optional[str] = None
    audio: typing.Optional["GroupsGroupAudio"] = None
    articles: typing.Optional[int] = None
    recognize_photo: typing.Optional[int] = None
    city_id: typing.Optional[int] = None
    city_name: typing.Optional[str] = None
    contacts: typing.Optional["BaseBoolInt"] = None
    links: typing.Optional["BaseBoolInt"] = None
    sections_list: typing.Optional[typing.List["GroupsSectionsListItem"]] = None
    main_section: typing.Optional["GroupsGroupFullSection"] = None
    secondary_section: typing.Optional["GroupsGroupFullSection"] = None
    age_limits: typing.Optional["GroupsGroupAgeLimits"] = None
    country_id: typing.Optional[int] = None
    country_name: typing.Optional[str] = None
    description: typing.Optional[str] = None
    docs: typing.Optional["GroupsGroupDocs"] = None
    events: typing.Optional["BaseBoolInt"] = None
    obscene_filter: typing.Optional["BaseBoolInt"] = None
    obscene_stopwords: typing.Optional["BaseBoolInt"] = None
    obscene_words: typing.Optional[typing.List[str]] = None
    event_group_id: typing.Optional[int] = None
    photos: typing.Optional["GroupsGroupPhotos"] = None
    public_category: typing.Optional[int] = None
    public_category_list: typing.Optional[
        typing.List["GroupsGroupPublicCategoryList"]
    ] = None
    public_date: typing.Optional[str] = None
    public_date_label: typing.Optional[str] = None
    public_subcategory: typing.Optional[int] = None
    rss: typing.Optional[str] = None
    start_date: typing.Optional[int] = None
    finish_date: typing.Optional[int] = None
    subject: typing.Optional[int] = None
    subject_list: typing.Optional[typing.List["GroupsSubjectItem"]] = None
    suggested_privacy: typing.Optional["GroupsGroupSuggestedPrivacy"] = None
    title: typing.Optional[str] = None
    topics: typing.Optional["GroupsGroupTopics"] = None
    twitter: typing.Optional["GroupsSettingsTwitter"] = None
    video: typing.Optional["GroupsGroupVideo"] = None
    wall: typing.Optional["GroupsGroupWall"] = None
    website: typing.Optional[str] = None
    phone: typing.Optional[str] = None
    email: typing.Optional[str] = None
    wiki: typing.Optional["GroupsGroupWiki"] = None


class GetTokenPermissionsResponseModel(BaseResponse):
    mask: typing.Optional[int] = None
    permissions: typing.Optional[typing.List["GroupsTokenPermissionSetting"]] = None


class GetObjectExtendedResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroupFull"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List[int]] = None


class IsMemberExtendedResponseModel(BaseResponse):
    member: typing.Optional["BaseBoolInt"] = None
    invitation: typing.Optional["BaseBoolInt"] = None
    can_invite: typing.Optional["BaseBoolInt"] = None
    can_recall: typing.Optional["BaseBoolInt"] = None
    request: typing.Optional["BaseBoolInt"] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["GroupsGroup"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddAddressResponse",
    "AddCallbackServerResponse",
    "AddCallbackServerResponseModel",
    "AddLinkResponse",
    "BaseBoolInt",
    "CreateResponse",
    "EditAddressResponse",
    "GetAddressesResponse",
    "GetAddressesResponseModel",
    "GetBannedResponse",
    "GetBannedResponseModel",
    "GetByIdObjectLegacyResponse",
    "GetCallbackConfirmationCodeResponse",
    "GetCallbackConfirmationCodeResponseModel",
    "GetCallbackServersResponse",
    "GetCallbackServersResponseModel",
    "GetCallbackSettingsResponse",
    "GetCatalogInfoExtendedResponse",
    "GetCatalogInfoExtendedResponseModel",
    "GetCatalogInfoResponse",
    "GetCatalogInfoResponseModel",
    "GetCatalogResponse",
    "GetCatalogResponseModel",
    "GetInvitedUsersResponse",
    "GetInvitedUsersResponseModel",
    "GetInvitesExtendedResponse",
    "GetInvitesExtendedResponseModel",
    "GetInvitesResponse",
    "GetInvitesResponseModel",
    "GetLongPollServerResponse",
    "GetLongPollSettingsResponse",
    "GetMembersFieldsResponse",
    "GetMembersFieldsResponseModel",
    "GetMembersFilterResponse",
    "GetMembersFilterResponseModel",
    "GetMembersResponse",
    "GetMembersResponseModel",
    "GetObjectExtendedResponse",
    "GetObjectExtendedResponseModel",
    "GetRequestsFieldsResponse",
    "GetRequestsFieldsResponseModel",
    "GetRequestsResponse",
    "GetRequestsResponseModel",
    "GetResponse",
    "GetResponseModel",
    "GetSettingsResponse",
    "GetSettingsResponseModel",
    "GetTagListResponse",
    "GetTokenPermissionsResponse",
    "GetTokenPermissionsResponseModel",
    "GroupsAddress",
    "GroupsBannedItem",
    "GroupsCallbackServer",
    "GroupsCallbackSettings",
    "GroupsGroup",
    "GroupsGroupAccess",
    "GroupsGroupAgeLimits",
    "GroupsGroupAudio",
    "GroupsGroupCategory",
    "GroupsGroupCategoryFull",
    "GroupsGroupDocs",
    "GroupsGroupFull",
    "GroupsGroupFullSection",
    "GroupsGroupPhotos",
    "GroupsGroupPublicCategoryList",
    "GroupsGroupSuggestedPrivacy",
    "GroupsGroupTag",
    "GroupsGroupTopics",
    "GroupsGroupVideo",
    "GroupsGroupWall",
    "GroupsGroupWiki",
    "GroupsLinksItem",
    "GroupsLongPollServer",
    "GroupsLongPollSettings",
    "GroupsMemberRole",
    "GroupsMemberStatus",
    "GroupsMemberStatusFull",
    "GroupsSectionsListItem",
    "GroupsSettingsTwitter",
    "GroupsSubjectItem",
    "GroupsTokenPermissionSetting",
    "GroupsUserXtrRole",
    "IsMemberExtendedResponse",
    "IsMemberExtendedResponseModel",
    "IsMemberResponse",
    "IsMemberUserIdsExtendedResponse",
    "IsMemberUserIdsResponse",
    "SearchResponse",
    "SearchResponseModel",
    "UsersUserFull",
    "UsersUserMin",
)



import inspect
import typing

from vkbottle_types.objects import (
    SecureGiveEventStickerItem,
    SecureLevel,
    SecureSetCounterItem,
    SecureSmsNotification,
    SecureTokenChecked,
    SecureTransaction,
)
from vkbottle_types.responses.base_response import BaseResponse


class CheckTokenResponse(BaseResponse):
    response: SecureTokenChecked


class GetAppBalanceResponse(BaseResponse):
    response: int


class GetSMSHistoryResponse(BaseResponse):
    response: typing.List["SecureSmsNotification"]


class GetTransactionsHistoryResponse(BaseResponse):
    response: typing.List["SecureTransaction"]


class GetUserLevelResponse(BaseResponse):
    response: typing.List["SecureLevel"]


class GiveEventStickerResponse(BaseResponse):
    response: typing.List["SecureGiveEventStickerItem"]


class SendNotificationResponse(BaseResponse):
    response: typing.List[int]


class SetCounterArrayResponse(BaseResponse):
    response: typing.List["SecureSetCounterItem"]


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "CheckTokenResponse",
    "GetAppBalanceResponse",
    "GetSMSHistoryResponse",
    "GetTransactionsHistoryResponse",
    "GetUserLevelResponse",
    "GiveEventStickerResponse",
    "SecureGiveEventStickerItem",
    "SecureLevel",
    "SecureSetCounterItem",
    "SecureSmsNotification",
    "SecureTokenChecked",
    "SecureTransaction",
    "SendNotificationResponse",
    "SetCounterArrayResponse",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseBoolInt,
    OrdersAmount,
    OrdersOrder,
    OrdersSubscription,
)
from vkbottle_types.responses.base_response import BaseResponse


class CancelSubscriptionResponse(BaseResponse):
    response: BaseBoolInt


class ChangeStateResponse(BaseResponse):
    response: str


class GetAmountResponse(BaseResponse):
    response: typing.List["OrdersAmount"]


class GetByIdResponse(BaseResponse):
    response: typing.List["OrdersOrder"]


class GetUserSubscriptionByIdResponse(BaseResponse):
    response: OrdersSubscription


class GetUserSubscriptionsResponse(BaseResponse):
    response: "GetUserSubscriptionsResponseModel"


class GetResponse(BaseResponse):
    response: typing.List["OrdersOrder"]


class UpdateSubscriptionResponse(BaseResponse):
    response: BaseBoolInt


class GetUserSubscriptionsResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["OrdersSubscription"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "BaseBoolInt",
    "CancelSubscriptionResponse",
    "ChangeStateResponse",
    "GetAmountResponse",
    "GetByIdResponse",
    "GetResponse",
    "GetUserSubscriptionByIdResponse",
    "GetUserSubscriptionsResponse",
    "GetUserSubscriptionsResponseModel",
    "OrdersAmount",
    "OrdersOrder",
    "OrdersSubscription",
    "UpdateSubscriptionResponse",
)



import inspect
import typing

from vkbottle_types.objects import (
    BaseUploadServer,
    DocsDoc,
    DocsDocAttachmentType,
    DocsDocTypes,
    MessagesAudioMessage,
    MessagesGraffiti,
)
from vkbottle_types.responses.base_response import BaseResponse


class AddResponse(BaseResponse):
    response: int


class DocUploadResponse(BaseResponse):
    response: "DocUploadResponseModel"


class GetByIdResponse(BaseResponse):
    response: typing.List["DocsDoc"]


class GetTypesResponse(BaseResponse):
    response: "GetTypesResponseModel"


class GetUploadServerResponse(BaseResponse):
    response: BaseUploadServer


class GetResponse(BaseResponse):
    response: "GetResponseModel"


class SaveResponse(BaseResponse):
    response: "SaveResponseModel"


class SearchResponse(BaseResponse):
    response: "SearchResponseModel"


class DocUploadResponseModel(BaseResponse):
    file: typing.Optional[str] = None


class GetTypesResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DocsDocTypes"]] = None


class GetResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DocsDoc"]] = None


class SaveResponseModel(BaseResponse):
    type: typing.Optional["DocsDocAttachmentType"] = None
    audio_message: typing.Optional["MessagesAudioMessage"] = None
    doc: typing.Optional["DocsDoc"] = None
    graffiti: typing.Optional["MessagesGraffiti"] = None


class SearchResponseModel(BaseResponse):
    count: typing.Optional[int] = None
    items: typing.Optional[typing.List["DocsDoc"]] = None


for item in locals().copy().values():
    if inspect.isclass(item) and issubclass(item, BaseResponse):
        item.update_forward_refs()


__all__ = (
    "AddResponse",
    "BaseUploadServer",
    "DocUploadResponse",
    "DocUploadResponseModel",
    "DocsDoc",
    "DocsDocAttachmentType",
    "DocsDocTypes",
    "GetByIdResponse",
    "GetResponse",
    "GetResponseModel",
    "GetTypesResponse",
    "GetTypesResponseModel",
    "GetUploadServerResponse",
    "MessagesAudioMessage",
    "MessagesGraffiti",
    "SaveResponse",
    "SaveResponseModel",
    "SearchResponse",
    "SearchResponseModel",
)
